@@ -1,27 +1,25 @@
 import inspect
 import queue
-import sys
+import time
 import uuid
 import warnings
 from typing import Tuple, Any, List, Optional, Set
 
-from ._server import FakeBaseConnectionMixin, FakeServer, VersionType
-
-if sys.version_info >= (3, 11):
-    from typing import Self
-else:
-    from typing_extensions import Self
-
 import redis
 
 from fakeredis._fakesocket import FakeSocket
 from fakeredis._helpers import FakeSelector
 from . import _msgs as msgs
+from ._server import FakeBaseConnectionMixin, FakeServer, VersionType, ServerType
+from .typing import Self
 
 
 class FakeConnection(FakeBaseConnectionMixin, redis.Connection):
+    def __init__(*args: Any, **kwargs: Any) -> None:
+        FakeBaseConnectionMixin.__init__(*args, **kwargs)
+
     def connect(self) -> None:
-        super().connect()
+        super().connect()  # type: ignore
         # The selector is set in redis.Connection.connect() after _connect() is called
         self._selector: Optional[FakeSelector] = FakeSelector(self._sock)
 
@@ -34,11 +32,11 @@ class FakeConnection(FakeBaseConnectionMixin, redis.Connection):
             lua_modules=self._lua_modules,
             client_info=dict(
                 id=3,
-                addr="127.0.0.1:57275",
-                laddr="127.0.0.1:6379",
+                addr="127.0.0.1:57275",  # TODO get IP
+                laddr="127.0.0.1:6379",  # TODO get IP
                 fd=8,
                 name="",
-                age=16,
+                _created=int(time.time()),
                 idle=0,
                 flags="N",
                 db=0,
@@ -79,8 +77,10 @@ class FakeConnection(FakeBaseConnectionMixin, redis.Connection):
     def _decode(self, response: Any) -> Any:
         if isinstance(response, list):
             return [self._decode(item) for item in response]
+        elif isinstance(response, dict):
+            return {self._decode(k): self._decode(v) for k, v in response.items()}
         elif isinstance(response, bytes):
-            return self.encoder.decode(response)
+            return self.encoder.decode(response)  # type: ignore
         else:
             return response
 
@@ -119,12 +119,11 @@ class FakeRedisMixin:
         *args: Any,
         server: Optional[FakeServer] = None,
         version: VersionType = (7,),
-        server_type: str = "redis",
+        server_type: ServerType = "redis",
         lua_modules: Optional[Set[str]] = None,
         **kwargs: Any,
     ) -> None:
-        # Interpret the positional and keyword arguments according to the
-        # version of redis in use.
+        # Interpret the positional and keyword arguments according to the version of redis in use.
         parameters = list(inspect.signature(redis.Redis.__init__).parameters.values())[1:]
         # Convert args => kwargs
         kwargs.update({parameters[i].name: args[i] for i in range(len(args))})
@@ -161,6 +160,7 @@ class FakeRedisMixin:
                 "client_name",
                 "connected",
                 "server",
+                "protocol",
             }
             connection_kwargs = {
                 "connection_class": FakeConnection,
@@ -187,9 +187,9 @@ class FakeRedisMixin:
         return cls(connection_pool=pool, *args, **kwargs)
 
 
-class FakeStrictRedis(FakeRedisMixin, redis.StrictRedis):  # type: ignore
+class FakeStrictRedis(FakeRedisMixin, redis.StrictRedis):
     pass
 
 
-class FakeRedis(FakeRedisMixin, redis.Redis):  # type: ignore
+class FakeRedis(FakeRedisMixin, redis.Redis):
     pass
